@@ -1,7 +1,7 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-8.
+# Conversion routines for ISO-8859-9.
 # Copyright (C) 2002-2016 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_8;
+package Locale::RecodeData::ISO_8859_9;
 
 use strict;
 
@@ -187,7 +187,7 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0xfffd,
+    0x00a1,
     0x00a2,
     0x00a3,
     0x00a4,
@@ -196,7 +196,7 @@ my @to_ucs4 = (
     0x00a7,
     0x00a8,
     0x00a9,
-    0x00d7,
+    0x00aa,
     0x00ab,
     0x00ac,
     0x00ad,
@@ -212,76 +212,76 @@ my @to_ucs4 = (
     0x00b7,
     0x00b8,
     0x00b9,
-    0x00f7,
+    0x00ba,
     0x00bb,
     0x00bc,
     0x00bd,
     0x00be,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0x2017,
-    0x05d0,
-    0x05d1,
-    0x05d2,
-    0x05d3,
-    0x05d4,
-    0x05d5,
-    0x05d6,
-    0x05d7,
-    0x05d8,
-    0x05d9,
-    0x05da,
-    0x05db,
-    0x05dc,
-    0x05dd,
-    0x05de,
-    0x05df,
-    0x05e0,
-    0x05e1,
-    0x05e2,
-    0x05e3,
-    0x05e4,
-    0x05e5,
-    0x05e6,
-    0x05e7,
-    0x05e8,
-    0x05e9,
-    0x05ea,
-    0xfffd,
-    0xfffd,
-    0x200e,
-    0x200f,
-    0xfffd,
+    0x00bf,
+    0x00c0,
+    0x00c1,
+    0x00c2,
+    0x00c3,
+    0x00c4,
+    0x00c5,
+    0x00c6,
+    0x00c7,
+    0x00c8,
+    0x00c9,
+    0x00ca,
+    0x00cb,
+    0x00cc,
+    0x00cd,
+    0x00ce,
+    0x00cf,
+    0x011e,
+    0x00d1,
+    0x00d2,
+    0x00d3,
+    0x00d4,
+    0x00d5,
+    0x00d6,
+    0x00d7,
+    0x00d8,
+    0x00d9,
+    0x00da,
+    0x00db,
+    0x00dc,
+    0x0130,
+    0x015e,
+    0x00df,
+    0x00e0,
+    0x00e1,
+    0x00e2,
+    0x00e3,
+    0x00e4,
+    0x00e5,
+    0x00e6,
+    0x00e7,
+    0x00e8,
+    0x00e9,
+    0x00ea,
+    0x00eb,
+    0x00ec,
+    0x00ed,
+    0x00ee,
+    0x00ef,
+    0x011f,
+    0x00f1,
+    0x00f2,
+    0x00f3,
+    0x00f4,
+    0x00f5,
+    0x00f6,
+    0x00f7,
+    0x00f8,
+    0x00f9,
+    0x00fa,
+    0x00fb,
+    0x00fc,
+    0x0131,
+    0x015f,
+    0x00ff,
 );
 
 my @to_utf8 = (
@@ -446,7 +446,7 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xef\xbf\xbd",
+    "\xc2\xa1",
     "\xc2\xa2",
     "\xc2\xa3",
     "\xc2\xa4",
@@ -455,7 +455,7 @@ my @to_utf8 = (
     "\xc2\xa7",
     "\xc2\xa8",
     "\xc2\xa9",
-    "\xc3\x97",
+    "\xc2\xaa",
     "\xc2\xab",
     "\xc2\xac",
     "\xc2\xad",
@@ -471,76 +471,76 @@ my @to_utf8 = (
     "\xc2\xb7",
     "\xc2\xb8",
     "\xc2\xb9",
-    "\xc3\xb7",
+    "\xc2\xba",
     "\xc2\xbb",
     "\xc2\xbc",
     "\xc2\xbd",
     "\xc2\xbe",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xe2\x80\x97",
-    "\xd7\x90",
-    "\xd7\x91",
-    "\xd7\x92",
-    "\xd7\x93",
-    "\xd7\x94",
-    "\xd7\x95",
-    "\xd7\x96",
-    "\xd7\x97",
-    "\xd7\x98",
-    "\xd7\x99",
-    "\xd7\x9a",
-    "\xd7\x9b",
-    "\xd7\x9c",
-    "\xd7\x9d",
-    "\xd7\x9e",
-    "\xd7\x9f",
-    "\xd7\xa0",
-    "\xd7\xa1",
-    "\xd7\xa2",
-    "\xd7\xa3",
-    "\xd7\xa4",
-    "\xd7\xa5",
-    "\xd7\xa6",
-    "\xd7\xa7",
-    "\xd7\xa8",
-    "\xd7\xa9",
-    "\xd7\xaa",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xe2\x80\x8e",
-    "\xe2\x80\x8f",
-    "\xef\xbf\xbd",
+    "\xc2\xbf",
+    "\xc3\x80",
+    "\xc3\x81",
+    "\xc3\x82",
+    "\xc3\x83",
+    "\xc3\x84",
+    "\xc3\x85",
+    "\xc3\x86",
+    "\xc3\x87",
+    "\xc3\x88",
+    "\xc3\x89",
+    "\xc3\x8a",
+    "\xc3\x8b",
+    "\xc3\x8c",
+    "\xc3\x8d",
+    "\xc3\x8e",
+    "\xc3\x8f",
+    "\xc4\x9e",
+    "\xc3\x91",
+    "\xc3\x92",
+    "\xc3\x93",
+    "\xc3\x94",
+    "\xc3\x95",
+    "\xc3\x96",
+    "\xc3\x97",
+    "\xc3\x98",
+    "\xc3\x99",
+    "\xc3\x9a",
+    "\xc3\x9b",
+    "\xc3\x9c",
+    "\xc4\xb0",
+    "\xc5\x9e",
+    "\xc3\x9f",
+    "\xc3\xa0",
+    "\xc3\xa1",
+    "\xc3\xa2",
+    "\xc3\xa3",
+    "\xc3\xa4",
+    "\xc3\xa5",
+    "\xc3\xa6",
+    "\xc3\xa7",
+    "\xc3\xa8",
+    "\xc3\xa9",
+    "\xc3\xaa",
+    "\xc3\xab",
+    "\xc3\xac",
+    "\xc3\xad",
+    "\xc3\xae",
+    "\xc3\xaf",
+    "\xc4\x9f",
+    "\xc3\xb1",
+    "\xc3\xb2",
+    "\xc3\xb3",
+    "\xc3\xb4",
+    "\xc3\xb5",
+    "\xc3\xb6",
+    "\xc3\xb7",
+    "\xc3\xb8",
+    "\xc3\xb9",
+    "\xc3\xba",
+    "\xc3\xbb",
+    "\xc3\xbc",
+    "\xc4\xb1",
+    "\xc5\x9f",
+    "\xc3\xbf",
 );
 
 my %from_ucs4 = (
@@ -705,6 +705,7 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
+    0x000000a1 => "\xa1",
     0x000000a2 => "\xa2",
     0x000000a3 => "\xa3",
     0x000000a4 => "\xa4",
@@ -713,6 +714,7 @@ my %from_ucs4 = (
     0x000000a7 => "\xa7",
     0x000000a8 => "\xa8",
     0x000000a9 => "\xa9",
+    0x000000aa => "\xaa",
     0x000000ab => "\xab",
     0x000000ac => "\xac",
     0x000000ad => "\xad",
@@ -728,42 +730,76 @@ my %from_ucs4 = (
     0x000000b7 => "\xb7",
     0x000000b8 => "\xb8",
     0x000000b9 => "\xb9",
+    0x000000ba => "\xba",
     0x000000bb => "\xbb",
     0x000000bc => "\xbc",
     0x000000bd => "\xbd",
     0x000000be => "\xbe",
-    0x000000d7 => "\xaa",
-    0x000000f7 => "\xba",
-    0x000005d0 => "\xe0",
-    0x000005d1 => "\xe1",
-    0x000005d2 => "\xe2",
-    0x000005d3 => "\xe3",
-    0x000005d4 => "\xe4",
-    0x000005d5 => "\xe5",
-    0x000005d6 => "\xe6",
-    0x000005d7 => "\xe7",
-    0x000005d8 => "\xe8",
-    0x000005d9 => "\xe9",
-    0x000005da => "\xea",
-    0x000005db => "\xeb",
-    0x000005dc => "\xec",
-    0x000005dd => "\xed",
-    0x000005de => "\xee",
-    0x000005df => "\xef",
-    0x000005e0 => "\xf0",
-    0x000005e1 => "\xf1",
-    0x000005e2 => "\xf2",
-    0x000005e3 => "\xf3",
-    0x000005e4 => "\xf4",
-    0x000005e5 => "\xf5",
-    0x000005e6 => "\xf6",
-    0x000005e7 => "\xf7",
-    0x000005e8 => "\xf8",
-    0x000005e9 => "\xf9",
-    0x000005ea => "\xfa",
-    0x0000200e => "\xfd",
-    0x0000200f => "\xfe",
-    0x00002017 => "\xdf",
+    0x000000bf => "\xbf",
+    0x000000c0 => "\xc0",
+    0x000000c1 => "\xc1",
+    0x000000c2 => "\xc2",
+    0x000000c3 => "\xc3",
+    0x000000c4 => "\xc4",
+    0x000000c5 => "\xc5",
+    0x000000c6 => "\xc6",
+    0x000000c7 => "\xc7",
+    0x000000c8 => "\xc8",
+    0x000000c9 => "\xc9",
+    0x000000ca => "\xca",
+    0x000000cb => "\xcb",
+    0x000000cc => "\xcc",
+    0x000000cd => "\xcd",
+    0x000000ce => "\xce",
+    0x000000cf => "\xcf",
+    0x000000d1 => "\xd1",
+    0x000000d2 => "\xd2",
+    0x000000d3 => "\xd3",
+    0x000000d4 => "\xd4",
+    0x000000d5 => "\xd5",
+    0x000000d6 => "\xd6",
+    0x000000d7 => "\xd7",
+    0x000000d8 => "\xd8",
+    0x000000d9 => "\xd9",
+    0x000000da => "\xda",
+    0x000000db => "\xdb",
+    0x000000dc => "\xdc",
+    0x000000df => "\xdf",
+    0x000000e0 => "\xe0",
+    0x000000e1 => "\xe1",
+    0x000000e2 => "\xe2",
+    0x000000e3 => "\xe3",
+    0x000000e4 => "\xe4",
+    0x000000e5 => "\xe5",
+    0x000000e6 => "\xe6",
+    0x000000e7 => "\xe7",
+    0x000000e8 => "\xe8",
+    0x000000e9 => "\xe9",
+    0x000000ea => "\xea",
+    0x000000eb => "\xeb",
+    0x000000ec => "\xec",
+    0x000000ed => "\xed",
+    0x000000ee => "\xee",
+    0x000000ef => "\xef",
+    0x000000f1 => "\xf1",
+    0x000000f2 => "\xf2",
+    0x000000f3 => "\xf3",
+    0x000000f4 => "\xf4",
+    0x000000f5 => "\xf5",
+    0x000000f6 => "\xf6",
+    0x000000f7 => "\xf7",
+    0x000000f8 => "\xf8",
+    0x000000f9 => "\xf9",
+    0x000000fa => "\xfa",
+    0x000000fb => "\xfb",
+    0x000000fc => "\xfc",
+    0x000000ff => "\xff",
+    0x0000011e => "\xd0",
+    0x0000011f => "\xf0",
+    0x00000130 => "\xdd",
+    0x00000131 => "\xfd",
+    0x0000015e => "\xde",
+    0x0000015f => "\xfe",
 );
 
 sub _recode
@@ -791,7 +827,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_8 - Conversion routines for ISO-8859-8
+Locale::RecodeData::ISO_8859_9 - Conversion routines for ISO-8859-9
 
 =head1 SYNOPSIS
 
@@ -800,7 +836,7 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-8.
+routines for ISO-8859-9.
 
 =head1 COMMENTS
 
@@ -808,10 +844,11 @@ The following comments have been extracted from the original charmap:
 
  version: 1.0
   source: ECMA registry
- alias ISO-IR-138
- alias ISO_8859-8:1988
- alias ISO_8859-8
- alias HEBREW
+ alias ISO-IR-148
+ alias ISO_8859-9:1989
+ alias ISO_8859-9
+ alias LATIN5
+ alias L5
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -984,6 +1021,7 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
+    A1 |  000000A1 | INVERTED EXCLAMATION MARK
     A2 |  000000A2 | CENT SIGN
     A3 |  000000A3 | POUND SIGN
     A4 |  000000A4 | CURRENCY SIGN
@@ -992,7 +1030,7 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     A7 |  000000A7 | SECTION SIGN
     A8 |  000000A8 | DIAERESIS
     A9 |  000000A9 | COPYRIGHT SIGN
-    AA |  000000D7 | MULTIPLICATION SIGN
+    AA |  000000AA | FEMININE ORDINAL INDICATOR
     AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
     AC |  000000AC | NOT SIGN
     AD |  000000AD | SOFT HYPHEN
@@ -1008,41 +1046,76 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     B7 |  000000B7 | MIDDLE DOT
     B8 |  000000B8 | CEDILLA
     B9 |  000000B9 | SUPERSCRIPT ONE
-    BA |  000000F7 | DIVISION SIGN
+    BA |  000000BA | MASCULINE ORDINAL INDICATOR
     BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
     BC |  000000BC | VULGAR FRACTION ONE QUARTER
     BD |  000000BD | VULGAR FRACTION ONE HALF
     BE |  000000BE | VULGAR FRACTION THREE QUARTERS
-    DF |  00002017 | DOUBLE LOW LINE
-    E0 |  000005D0 | HEBREW LETTER ALEF
-    E1 |  000005D1 | HEBREW LETTER BET
-    E2 |  000005D2 | HEBREW LETTER GIMEL
-    E3 |  000005D3 | HEBREW LETTER DALET
-    E4 |  000005D4 | HEBREW LETTER HE
-    E5 |  000005D5 | HEBREW LETTER VAV
-    E6 |  000005D6 | HEBREW LETTER ZAYIN
-    E7 |  000005D7 | HEBREW LETTER HET
-    E8 |  000005D8 | HEBREW LETTER TET
-    E9 |  000005D9 | HEBREW LETTER YOD
-    EA |  000005DA | HEBREW LETTER FINAL KAF
-    EB |  000005DB | HEBREW LETTER KAF
-    EC |  000005DC | HEBREW LETTER LAMED
-    ED |  000005DD | HEBREW LETTER FINAL MEM
-    EE |  000005DE | HEBREW LETTER MEM
-    EF |  000005DF | HEBREW LETTER FINAL NUN
-    F0 |  000005E0 | HEBREW LETTER NUN
-    F1 |  000005E1 | HEBREW LETTER SAMEKH
-    F2 |  000005E2 | HEBREW LETTER AYIN
-    F3 |  000005E3 | HEBREW LETTER FINAL PE
-    F4 |  000005E4 | HEBREW LETTER PE
-    F5 |  000005E5 | HEBREW LETTER FINAL TSADI
-    F6 |  000005E6 | HEBREW LETTER TSADI
-    F7 |  000005E7 | HEBREW LETTER QOF
-    F8 |  000005E8 | HEBREW LETTER RESH
-    F9 |  000005E9 | HEBREW LETTER SHIN
-    FA |  000005EA | HEBREW LETTER TAV
-    FD |  0000200E | LEFT-TO-RIGHT MARK
-    FE |  0000200F | RIGHT-TO-LEFT MARK
+    BF |  000000BF | INVERTED QUESTION MARK
+    C0 |  000000C0 | LATIN CAPITAL LETTER A WITH GRAVE
+    C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
+    C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
+    C3 |  000000C3 | LATIN CAPITAL LETTER A WITH TILDE
+    C4 |  000000C4 | LATIN CAPITAL LETTER A WITH DIAERESIS
+    C5 |  000000C5 | LATIN CAPITAL LETTER A WITH RING ABOVE
+    C6 |  000000C6 | LATIN CAPITAL LETTER AE
+    C7 |  000000C7 | LATIN CAPITAL LETTER C WITH CEDILLA
+    C8 |  000000C8 | LATIN CAPITAL LETTER E WITH GRAVE
+    C9 |  000000C9 | LATIN CAPITAL LETTER E WITH ACUTE
+    CA |  000000CA | LATIN CAPITAL LETTER E WITH CIRCUMFLEX
+    CB |  000000CB | LATIN CAPITAL LETTER E WITH DIAERESIS
+    CC |  000000CC | LATIN CAPITAL LETTER I WITH GRAVE
+    CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
+    CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
+    CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
+    D0 |  0000011E | LATIN CAPITAL LETTER G WITH BREVE
+    D1 |  000000D1 | LATIN CAPITAL LETTER N WITH TILDE
+    D2 |  000000D2 | LATIN CAPITAL LETTER O WITH GRAVE
+    D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
+    D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
+    D5 |  000000D5 | LATIN CAPITAL LETTER O WITH TILDE
+    D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
+    D7 |  000000D7 | MULTIPLICATION SIGN
+    D8 |  000000D8 | LATIN CAPITAL LETTER O WITH STROKE
+    D9 |  000000D9 | LATIN CAPITAL LETTER U WITH GRAVE
+    DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
+    DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
+    DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
+    DD |  00000130 | LATIN CAPITAL LETTER I WITH DOT ABOVE
+    DE |  0000015E | LATIN CAPITAL LETTER S WITH CEDILLA
+    DF |  000000DF | LATIN SMALL LETTER SHARP S (German)
+    E0 |  000000E0 | LATIN SMALL LETTER A WITH GRAVE
+    E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
+    E2 |  000000E2 | LATIN SMALL LETTER A WITH CIRCUMFLEX
+    E3 |  000000E3 | LATIN SMALL LETTER A WITH TILDE
+    E4 |  000000E4 | LATIN SMALL LETTER A WITH DIAERESIS
+    E5 |  000000E5 | LATIN SMALL LETTER A WITH RING ABOVE
+    E6 |  000000E6 | LATIN SMALL LETTER AE
+    E7 |  000000E7 | LATIN SMALL LETTER C WITH CEDILLA
+    E8 |  000000E8 | LATIN SMALL LETTER E WITH GRAVE
+    E9 |  000000E9 | LATIN SMALL LETTER E WITH ACUTE
+    EA |  000000EA | LATIN SMALL LETTER E WITH CIRCUMFLEX
+    EB |  000000EB | LATIN SMALL LETTER E WITH DIAERESIS
+    EC |  000000EC | LATIN SMALL LETTER I WITH GRAVE
+    ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
+    EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
+    EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
+    F0 |  0000011F | LATIN SMALL LETTER G WITH BREVE
+    F1 |  000000F1 | LATIN SMALL LETTER N WITH TILDE
+    F2 |  000000F2 | LATIN SMALL LETTER O WITH GRAVE
+    F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
+    F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
+    F5 |  000000F5 | LATIN SMALL LETTER O WITH TILDE
+    F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
+    F7 |  000000F7 | DIVISION SIGN
+    F8 |  000000F8 | LATIN SMALL LETTER O WITH STROKE
+    F9 |  000000F9 | LATIN SMALL LETTER U WITH GRAVE
+    FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
+    FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
+    FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
+    FD |  00000131 | LATIN SMALL LETTER DOTLESS I
+    FE |  0000015F | LATIN SMALL LETTER S WITH CEDILLA
+    FF |  000000FF | LATIN SMALL LETTER Y WITH DIAERESIS
 
 
 =head1 AUTHOR
